@@ -1,7 +1,7 @@
 /*
  *  callback.c
  *
- *  Copyright (c) 2006-2018 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2020 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -267,23 +267,6 @@ void cb_event(alpm_event_t *event)
 				printf(_("loading package files...\n"));
 			}
 			break;
-		case ALPM_EVENT_DELTA_INTEGRITY_START:
-			printf(_("checking delta integrity...\n"));
-			break;
-		case ALPM_EVENT_DELTA_PATCHES_START:
-			printf(_("applying deltas...\n"));
-			break;
-		case ALPM_EVENT_DELTA_PATCH_START:
-			printf(_("generating %s with %s... "),
-					event->delta_patch.delta->to,
-					event->delta_patch.delta->delta);
-			break;
-		case ALPM_EVENT_DELTA_PATCH_DONE:
-			printf(_("success!\n"));
-			break;
-		case ALPM_EVENT_DELTA_PATCH_FAILED:
-			printf(_("failed.\n"));
-			break;
 		case ALPM_EVENT_SCRIPTLET_INFO:
 			fputs(event->scriptlet_info.line, stdout);
 			break;
@@ -355,8 +338,6 @@ void cb_event(alpm_event_t *event)
 		case ALPM_EVENT_KEYRING_DONE:
 		case ALPM_EVENT_KEY_DOWNLOAD_DONE:
 		case ALPM_EVENT_LOAD_DONE:
-		case ALPM_EVENT_DELTA_INTEGRITY_DONE:
-		case ALPM_EVENT_DELTA_PATCHES_DONE:
 		case ALPM_EVENT_DISKSPACE_DONE:
 		case ALPM_EVENT_RETRIEVE_DONE:
 		case ALPM_EVENT_RETRIEVE_FAILED:
@@ -475,16 +456,13 @@ void cb_question(alpm_question_t *question)
 		case ALPM_QUESTION_IMPORT_KEY:
 			{
 				alpm_question_import_key_t *q = &question->import_key;
-				char created[12];
-				time_t time = (time_t)q->key->created;
-				strftime(created, 12, "%Y-%m-%d", localtime(&time));
-
-				if(q->key->revoked) {
-					q->import = yesno(_("Import PGP key %u%c/%s, \"%s\", created: %s (revoked)?"),
-							q->key->length, q->key->pubkey_algo, q->key->fingerprint, q->key->uid, created);
+				/* the uid is unknown with db signatures */
+				if (q->key->uid == NULL) {
+					q->import = yesno(_("Import PGP key %s?"),
+							q->key->fingerprint);
 				} else {
-					q->import = yesno(_("Import PGP key %u%c/%s, \"%s\", created: %s?"),
-							q->key->length, q->key->pubkey_algo, q->key->fingerprint, q->key->uid, created);
+					q->import = yesno(_("Import PGP key %s, \"%s\"?"),
+							q->key->fingerprint, q->key->uid);
 				}
 			}
 			break;
@@ -784,7 +762,7 @@ void cb_dl_progress(const char *filename, off_t file_xfered, off_t file_total)
 
 	len = strlen(filename);
 	fname = malloc(len + 1);
-	memcpy(fname, filename, len);
+	memcpy(fname, filename, len + 1);
 	/* strip package or DB extension for cleaner look */
 	if((p = strstr(fname, ".pkg")) || (p = strstr(fname, ".db")) || (p = strstr(fname, ".files"))) {
 		/* tack on a .sig suffix for signatures */
@@ -796,13 +774,13 @@ void cb_dl_progress(const char *filename, off_t file_xfered, off_t file_total)
 		} else {
 			len = p - fname;
 		}
+		fname[len] = '\0';
 	}
-	fname[len] = '\0';
 
 	/* 1 space + filenamelen + 1 space + 6 for size + 1 space + 3 for label +
-	 * + 2 spaces + 4 for rate + 1 for label + 2 for /s + 1 space +
-	 * 8 for eta, gives us the magic 30 */
-	filenamelen = infolen - 30;
+	 * + 2 spaces + 4 for rate + 1 space + 3 for label + 2 for /s + 1 space +
+	 * 8 for eta, gives us the magic 33 */
+	filenamelen = infolen - 33;
 	/* see printf() code, we omit 'HH:' in these conditions */
 	if(eta_h == 0 || eta_h >= 100) {
 		filenamelen += 3;
@@ -823,7 +801,7 @@ void cb_dl_progress(const char *filename, off_t file_xfered, off_t file_total)
 		int i = filenamelen - 3;
 		wchar_t *wcp = wcfname;
 		/* grab the max number of char columns we can fill */
-		while(i > 0 && wcwidth(*wcp) < i) {
+		while(wcwidth(*wcp) < i) {
 			i -= wcwidth(*wcp);
 			wcp++;
 		}
@@ -837,16 +815,16 @@ void cb_dl_progress(const char *filename, off_t file_xfered, off_t file_total)
 	xfered_human = humanize_size(xfered, '\0', -1, &xfered_label);
 
 	printf(" %ls%-*s ", wcfname, padwid, "");
-	/* We will show 1.62M/s, 11.6M/s, but 116K/s and 1116K/s */
+	/* We will show 1.62 MiB/s, 11.6 MiB/s, but 116 KiB/s and 1116 KiB/s */
 	if(rate_human < 9.995) {
-		printf("%6.1f %3s  %4.2f%c/s ",
-				xfered_human, xfered_label, rate_human, rate_label[0]);
+		printf("%6.1f %3s  %4.2f %3s/s ",
+				xfered_human, xfered_label, rate_human, rate_label);
 	} else if(rate_human < 99.95) {
-		printf("%6.1f %3s  %4.1f%c/s ",
-				xfered_human, xfered_label, rate_human, rate_label[0]);
+		printf("%6.1f %3s  %4.1f %3s/s ",
+				xfered_human, xfered_label, rate_human, rate_label);
 	} else {
-		printf("%6.1f %3s  %4.f%c/s ",
-				xfered_human, xfered_label, rate_human, rate_label[0]);
+		printf("%6.1f %3s  %4.f %3s/s ",
+				xfered_human, xfered_label, rate_human, rate_label);
 	}
 	if(eta_h == 0) {
 		printf("%02u:%02u", eta_m, eta_s);
